==> jscommunicator-1.0.21.tgz: package/lib/communicatorClient.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var genericTransactionalMail = require('./genericTransactionalMail');
var genericPromotionalMail = require('./genericPromotionalMail');
var genericTransactionalSms = require('./genericTransactionalSms');
var genericPromotionalSms = require('./genericPromotionalSms');
var otpSms = require('./otpSms');
var patientPromoAndroidPush = require('./patientPromoAndroidPush');
var patientTransAndroidPush = require('./patientTransAndroidPush');
var patientPromoIosPush = require('./patientPromoIosPush');
var patientTransIosPush = require('./patientTransIosPush');

var CommunicatorClient = function () {
  function CommunicatorClient(host, config, appName) {
    _classCallCheck(this, CommunicatorClient);

    this.host = host;
    this.config = config;
    this.appName = appName;
  }

  _createClass(CommunicatorClient, [{
    key: 'getInstance',
    value: function getInstance(serviceType) {
      if (serviceType === "mailGenericTransactional") {
        return new genericTransactionalMail.MailGenericTransactional(this.host, this.config, this.appName);
      } else if (serviceType === "smsGenericTransactional") {
        return new genericTransactionalSms.SmsGenericTransactional(this.host, this.config, this.appName);
      } else if (serviceType === "mailGenericPromotional") {
        return new genericPromotionalMail.MailGenericPromotional(this.host, this.config, this.appName);
      } else if (serviceType === "smsGenericPromotional") {
        return new genericPromotionalSms.SmsGenericPromotional(this.host, this.config, this.appName);
      } else if (serviceType === "smsOtp") {
        return new otpSms.OtpSms(this.host, this.config, this.appName);
      } else if (serviceType === "patientPromoAndroidPush") {
        return new patientPromoAndroidPush.PatientPromoAndroidPush(this.host, this.config, this.appName);
      } else if (serviceType === "patientTransAndroidPush") {
        return new patientTransAndroidPush.PatientTransAndroidPush(this.host, this.config, this.appName);
      } else if (serviceType === "patientPromoIosPush") {
        return new patientPromoIosPush.PatientPromoIosPush(this.host, this.config, this.appName);
      } else if (serviceType === "patientTransIosPush") {
        return new patientTransIosPush.PatientTransIosPush(this.host, this.config, this.appName);
      } else {
        throw "unknown service type";
      }
    }
  }]);

  return CommunicatorClient;
}();

module.exports = {
  CommunicatorClient: CommunicatorClient
};

==> jscommunicator-1.0.27.tgz: package/lib/communicatorClient.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var genericTransactionalMail = require('./genericTransactionalMail');
var genericPromotionalMail = require('./genericPromotionalMail');
var genericTransactionalSms = require('./genericTransactionalSms');
var genericPromotionalSms = require('./genericPromotionalSms');
var otpSms = require('./otpSms');
var patientPromoAndroidPush = require('./patientPromoAndroidPush');
var patientTransAndroidPush = require('./patientTransAndroidPush');
var patientPromoIosPush = require('./patientPromoIosPush');
var patientTransIosPush = require('./patientTransIosPush');

var CommunicatorClient = function () {
  function CommunicatorClient(request, config, appName) {
    _classCallCheck(this, CommunicatorClient);

    console.log("-----------REQUEST --------------");
    console.log(request.headers);
    this.request = request;
    this.config = config;
    this.appName = appName;
  }

  _createClass(CommunicatorClient, [{
    key: 'getInstance',
    value: function getInstance(serviceType) {
      if (serviceType === "mailGenericTransactional") {
        return new genericTransactionalMail.MailGenericTransactional(this.request, this.config, this.appName);
      } else if (serviceType === "smsGenericTransactional") {
        return new genericTransactionalSms.SmsGenericTransactional(this.request, this.config, this.appName);
      } else if (serviceType === "mailGenericPromotional") {
        return new genericPromotionalMail.MailGenericPromotional(this.request, this.config, this.appName);
      } else if (serviceType === "smsGenericPromotional") {
        return new genericPromotionalSms.SmsGenericPromotional(this.request, this.config, this.appName);
      } else if (serviceType === "smsOtp") {
        return new otpSms.OtpSms(this.request, this.config, this.appName);
      } else if (serviceType === "patientPromoAndroidPush") {
        return new patientPromoAndroidPush.PatientPromoAndroidPush(this.request, this.config, this.appName);
      } else if (serviceType === "patientTransAndroidPush") {
        return new patientTransAndroidPush.PatientTransAndroidPush(this.request, this.config, this.appName);
      } else if (serviceType === "patientPromoIosPush") {
        return new patientPromoIosPush.PatientPromoIosPush(this.request, this.config, this.appName);
      } else if (serviceType === "patientTransIosPush") {
        return new patientTransIosPush.PatientTransIosPush(this.request, this.config, this.appName);
      } else {
        throw "unknown service type";
      }
    }
  }]);

  return CommunicatorClient;
}();

module.exports = {
  CommunicatorClient: CommunicatorClient
};
